/*
------------------------------------------------------------------
Provider:  Zip-Codes.com
Product:   U.S. ZIP Code Database Business - Place FIPS
------------------------------------------------------------------
This SQL Creates a new table named PlaceFIPS, 
related indexes, and extended column information.

This script is designed to work with MS SQL Server 2000 & 2005

Actions:
  1.) Drop Table PlaceFIPS if it exists
  2.) Creates Table named PlaceFIPS
  3.) Creates Indexes on table PlaceFIPS

Last Updated: 11/1/2022
------------------------------------------------------------------
*/


/* 1.) Drop Table if it Exists */
if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[PlaceFIPS]') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
drop table [dbo].[PlaceFIPS]
GO


/* 2.) Create Table */
CREATE TABLE [dbo].[PlaceFIPS] (
    [ZIPCODE] [char] (5) NOT NULL,
    [STATE] [char] (2),
    [STATEFIPS] [char] (2),
    [PLACEFIPS] [char] (5),
    [PLACENAME] [varchar] (255),
    [OID_PLACE_20] [varchar] (255),
    [GEOID_PLACE_20] [varchar] (255),
    [AREALAND_PLACE_20] [bigint],
    [AREAWATER_PLACE_20] [bigint],
    [MTFCC_PLACE_20] [varchar] (5),
    [MTFCC_TEXT_PLACE_20] [varchar] (255),
    [CLASSFP_PLACE_20] [varchar] (2),
    [CLASSFP_TEXT_PLACE_20] [varchar] (255),
    [FUNCSTAT_PLACE_20] [varchar] (1),
    [FUNCSTAT_TEXT_PLACE_20] [varchar] (255),
    [AREALAND_PART] [bigint],
    [AREAWATER_PART] [bigint],
    [OID_ZCTA5_20] [varchar] (255),
    [GEOID_ZCTA5_20] [varchar] (5),
    [NAMELSAD_ZCTA5_20] [varchar] (255),
    [AREALAND_ZCTA5_20] [bigint],
    [AREAWATER_ZCTA5_20] [bigint],
    [MTFCC_ZCTA5_20] [varchar] (255),
    [CLASSFP_ZCTA5_20] [varchar] (2),
    [FUNCSTAT_ZCTA5_20] [varchar] (1)
) ON [PRIMARY]
GO


/* 3.) Create Indexes on most searched fields */
CREATE  INDEX [Index_PlaceFIPS_ZIPCODE]					 ON [dbo].[PlaceFIPS]([ZIPCODE]) ON [PRIMARY]
CREATE  INDEX [Index_PlaceFIPS_STATE]					 ON [dbo].[PlaceFIPS]([STATE]) ON [PRIMARY]
CREATE  INDEX [Index_PlaceFIPS_STATEFIPS]				 ON [dbo].[PlaceFIPS]([STATEFIPS]) ON [PRIMARY]
CREATE  INDEX [Index_PlaceFIPS_PLACEFIPS]				 ON [dbo].[PlaceFIPS]([PLACEFIPS]) ON [PRIMARY]
CREATE  INDEX [Index_PlaceFIPS_PLACENAME]				 ON [dbo].[PlaceFIPS]([PLACENAME]) ON [PRIMARY]
GO

