/*
------------------------------------------------------------------
Provider:  Zip-Codes.com
Product:   U.S. ZIP Code Database Business - Place FIPS
------------------------------------------------------------------
This SQL Creates a new table named PlaceFIPS, 
related indexes, and extended column information.

This script is designed to work with MySQL

Actions:
  1.) Drop Table PlaceFIPS if it exists
  2.) Creates Table named PlaceFIPS
  3.) Creates Indexes on table PlaceFIPS

Last Updated: 11/1/2022
------------------------------------------------------------------
*/


/* 1.) Drop Table if it Exists */
DROP TABLE IF EXISTS PlaceFIPS;


/* 2.) Create Table */
CREATE TABLE PlaceFIPS (
	ZIPCODE char(5) NULL,
	STATE char(2) NULL,
	STATEFIPS char(2) NULL,
	PLACEFIPS char(5) NULL,
	PLACENAME varchar(255) NULL,
    OID_PLACE_20 varchar(255) NULL,
    GEOID_PLACE_20 varchar(255) NULL,
    AREALAND_PLACE_20 bigint,
    AREAWATER_PLACE_20 bigint,
    MTFCC_PLACE_20 varchar(5) NULL,
    MTFCC_TEXT_PLACE_20 varchar(255) NULL,
    CLASSFP_PLACE_20 varchar(2) NULL,
    CLASSFP_TEXT_PLACE_20 varchar(255) NULL,
    FUNCSTAT_PLACE_20 varchar(1) NULL,
    FUNCSTAT_TEXT_PLACE_20 varchar(255) NULL,
    AREALAND_PART bigint,
    AREAWATER_PART bigint,
    OID_ZCTA5_20 varchar(255) NULL,
    GEOID_ZCTA5_20 varchar(5) NULL,
    NAMELSAD_ZCTA5_20 varchar(255) NULL,
    AREALAND_ZCTA5_20 bigint,
    AREAWATER_ZCTA5_20 bigint,
    MTFCC_ZCTA5_20 varchar(255) NULL,
    CLASSFP_ZCTA5_20 varchar(2) NULL,
    FUNCSTAT_ZCTA5_20 varchar(1) NULL
);


/* 3.) Create Indexes on most searched fields */
CREATE INDEX Index_PlaceFIPS_ZIPCODE					 ON PlaceFIPS (ZIPCODE);
CREATE INDEX Index_PlaceFIPS_STATE						 ON PlaceFIPS (STATE);
CREATE INDEX Index_PlaceFIPS_STATEFIPS					 ON PlaceFIPS (STATEFIPS);
CREATE INDEX Index_PlaceFIPS_PLACEFIPS					 ON PlaceFIPS (PLACEFIPS);
CREATE INDEX Index_PlaceFIPS_PLACENAME					 ON PlaceFIPS (PLACENAME);
