/*
------------------------------------------------------------------
Provider:  Zip-Codes.com
Product:   U.S. ZIP Code Database Business
------------------------------------------------------------------
This SQL Creates a new table named ZIPCodes, 
related indexes, and extended column information.

This script is designed to work with MS SQL Server 2000 & 2005

Actions:
  1.) Drop Table ZIPCodes if it exists
  2.) Creates Table named ZIPCodes
  3.) Creates Indexes on table ZIPCodes
  4.) Creates Extended Column Information

Last Updated: 12/21/2007
------------------------------------------------------------------
*/


/* 1.) Drop Table if it Exists */
if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[ZIPCodes]') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
drop table [dbo].[ZIPCodes]
GO


/* 2.) Create Table */
CREATE TABLE [dbo].[ZIPCodes] (
	[ZipCode] [char] (5) NOT NULL,
	[PrimaryRecord] [char] (1),
	[Population] [int],
	[HouseholdsPerZipcode] [int],
	[WhitePopulation] [int],
	[BlackPopulation] [int],
	[HispanicPopulation] [int],
	[AsianPopulation] [int],
	[HawaiianPopulation] [int],
	[IndianPopulation] [int],
	[OtherPopulation] [int],
	[MalePopulation] [int],
	[FemalePopulation] [int],
	[PersonsPerHousehold] [decimal](4, 2),
	[AverageHouseValue] [int],
	[IncomePerHousehold] [int],
	[MedianAge] [decimal](3, 1),
	[MedianAgeMale] [decimal](3, 1),
	[MedianAgeFemale] [decimal](3, 1),
	[Latitude] [decimal](12, 6),
	[Longitude] [decimal](12, 6),
	[Elevation] [int],
	[State] [char] (2),
	[StateFullName] [varchar] (35) NULL,
	[CityType] [char] (1) NULL,
	[CityAliasAbbreviation] [varchar] (13) NULL,
	[AreaCode] [varchar] (55) NULL,
	[City] [varchar] (35) NULL,
	[CityAliasName] [varchar] (35) NULL,
	[County] [varchar] (45) NULL,
	[CountyFIPS] [char] (5) NULL,
	[StateFIPS] [char] (2) NULL,
	[TimeZone] [char] (2) NULL,
	[DayLightSaving] [char] (1) NULL,
	[MSA] [varchar] (35) NULL,
	[PMSA] [char] (4) NULL,
	[CSA] [char] (3) NULL,
	[CBSA] [char] (5) NULL,
	[CBSA_DIV] [char] (5) NULL,	
	[CBSA_Type] [char] (5) NULL,
	[CBSA_Name] [varchar] (150) NULL,
	[MSA_Name] [varchar] (150) NULL,
	[PMSA_Name] [varchar] (150) NULL,
	[Region] [varchar] (10) NULL,
	[Division] [varchar] (20) NULL,
	[MailingName] [char] (1) NULL,
	[NumberOfBusinesses] [int],
	[NumberOfEmployees] [int],
	[BusinessFirstQuarterPayroll] [int],
	[BusinessAnnualPayroll] [int],
	[BusinessEmploymentFlag] [char] (1) NULL,
	[GrowthRank] [int],
	[GrowingCountiesA] [int],
	[GrowingCountiesB] [int],
	[GrowthIncreaseNumber] [int],
	[GrowthIncreasePercentage] [decimal](3, 1),
	[CBSAPopulation] [int],
	[CBSADivisionPopulation] [int],
	[CongressionalDistrict] [varchar] (150) NULL,
	[CongressionalLandArea] [varchar] (150) NULL,
	[DeliveryResidential] [int],
	[DeliveryBusiness] [int],
	[DeliveryTotal] [int],
	[PreferredLastLineKey] [varchar] (10) NULL,
	[ClassificationCode] [char] (1) NULL,
	[MultiCounty] [char] (1) NULL,
	[CSAName] [varchar] (150) NULL,	
	[CBSA_DIV_Name] [varchar] (150) NULL,
	[CityStateKey] [char] (6) NULL,
	[PopulationEstimate] [int],
	[LandArea] [decimal](18, 6),
	[WaterArea] [decimal](18, 6),
	[CityAliasCode] [varchar] (5) NULL,
	[CityMixedCase] [varchar] (35) NULL,
	[CityAliasMixedCase] [varchar] (35) NULL,
	[BoxCount] [int],
	[SFDU] [int],
	[MFDU] [int],
	[StateANSI] [varchar] (2) NULL,
	[CountyANSI] [varchar] (3) NULL,
	[ZIPIntroDate] [varchar] (15) NULL,
	[AliasIntroDate] [varchar] (15) NULL,
	[FacilityCode] [char] (1) NULL,
	[CityDeliveryIndicator] [char] (1) NULL,
	[CarrierRouteRateSortation] [char] (1) NULL,
	[FinanceNumber] [varchar] (10) NULL,
	[UniqueZIPName] [char] (1) NULL,
	[SSAStateCountyCode] [varchar] (255) NULL,
	[MedicareCBSACode] [varchar] (255) NULL,
	[MedicareCBSAName] [varchar] (255) NULL,
	[MedicareCBSAType] [varchar] (255) NULL,
	[MedicareCBSAType] [varchar] (255) NULL,
	[MarketRatingAreaID] [int] NULL
) ON [PRIMARY]
GO


/* 3.) Create Indexes on most searched fields */
CREATE  INDEX [Index_ZIPCodes_ZipCode]				 ON [dbo].[ZIPCodes]([ZipCode]) ON [PRIMARY]
CREATE  INDEX [Index_ZIPCodes_State]				 ON [dbo].[ZIPCodes]([State]) ON [PRIMARY]
CREATE  INDEX [Index_ZIPCodes_County]				 ON [dbo].[ZIPCodes]([County]) ON [PRIMARY]
CREATE  INDEX [Index_ZIPCodes_AreaCode]				 ON [dbo].[ZIPCodes]([AreaCode]) ON [PRIMARY]
CREATE  INDEX [Index_ZIPCodes_City]					 ON [dbo].[ZIPCodes]([City]) ON [PRIMARY]
CREATE  INDEX [Index_ZIPCodes_Latitude]				 ON [dbo].[ZIPCodes]([Latitude]) ON [PRIMARY]
CREATE  INDEX [Index_ZIPCodes_Longitude]			 ON [dbo].[ZIPCodes]([Longitude]) ON [PRIMARY]
CREATE  INDEX [Index_ZIPCodes_PrimaryRecord]		 ON [dbo].[ZIPCodes]([PrimaryRecord]) ON [PRIMARY]
CREATE  INDEX [Index_ZIPCodes_CityStateKey]			 ON [dbo].[ZIPCodes]([CityStateKey]) ON [PRIMARY]
GO


/* 4.) Create Extended Column Information */
exec sp_addextendedproperty N'MS_Description', N'U.S. Zip Code Database Business (from www.zip-codes.com)', N'user', N'dbo', N'table', N'ZIPCodes'
exec sp_addextendedproperty N'MS_Description', N'00000-99999 Five digit numeric ZIP Code of the area.', N'user', N'dbo', N'table', N'ZIPCodes', N'column', N'ZipCode'
exec sp_addextendedproperty N'MS_Description', N'Character P denoting if this row is a Primary Record or not. Absence of character denotes a non-primary record.', N'user', N'dbo', N'table', N'ZIPCodes', N'column', N'PrimaryRecord'
exec sp_addextendedproperty N'MS_Description', N'The population of the ZIP Code based on 2000 Census data.', N'user', N'dbo', N'table', N'ZIPCodes', N'column', N'Population'
exec sp_addextendedproperty N'MS_Description', N'The estimated number of households of the ZIP Code based on 2000 Census data.', N'user', N'dbo', N'table', N'ZIPCodes', N'column', N'HouseholdsPerZipcode'
exec sp_addextendedproperty N'MS_Description', N'The estimated White/Caucasian Population of the ZIP Code based on 2000 Census data.', N'user', N'dbo', N'table', N'ZIPCodes', N'column', N'WhitePopulation'
exec sp_addextendedproperty N'MS_Description', N'The estimated Black/African American Population of the ZIP Code based on 2000 Census data.', N'user', N'dbo', N'table', N'ZIPCodes', N'column', N'BlackPopulation'
exec sp_addextendedproperty N'MS_Description', N'The estimated Hispanic Population of the ZIP Code based on 2000 Census data.', N'user', N'dbo', N'table', N'ZIPCodes', N'column', N'HispanicPopulation'
exec sp_addextendedproperty N'MS_Description', N'The estimated Asian Population of the ZIP Code based on 2000 Census data.', N'user', N'dbo', N'table', N'ZIPCodes', N'column', N'AsianPopulation'
exec sp_addextendedproperty N'MS_Description', N'The estimated Hawaiian or Pacific Islander Population of the ZIP Code based on 2000 Census data.', N'user', N'dbo', N'table', N'ZIPCodes', N'column', N'HawaiianPopulation'
exec sp_addextendedproperty N'MS_Description', N'The estimated American Indian and Alaska Native Population of the ZIP Code based on 2000 Census data.', N'user', N'dbo', N'table', N'ZIPCodes', N'column', N'IndianPopulation'
exec sp_addextendedproperty N'MS_Description', N'The estimated Population of all other races for the ZIP Code based on 2000 Census data.', N'user', N'dbo', N'table', N'ZIPCodes', N'column', N'OtherPopulation'
exec sp_addextendedproperty N'MS_Description', N'The estimated Male Population of the ZIP Code based on 2000 Census data.', N'user', N'dbo', N'table', N'ZIPCodes', N'column', N'MalePopulation'
exec sp_addextendedproperty N'MS_Description', N'The estimated Female Population of the ZIP Code based on 2000 Census data.', N'user', N'dbo', N'table', N'ZIPCodes', N'column', N'FemalePopulation'
exec sp_addextendedproperty N'MS_Description', N'The estimated average number of persons per household of the ZIP Code based on 2000 Census data.', N'user', N'dbo', N'table', N'ZIPCodes', N'column', N'PersonsPerHousehold'
exec sp_addextendedproperty N'MS_Description', N'The average house value in County based on 2000 Census data.', N'user', N'dbo', N'table', N'ZIPCodes', N'column', N'AverageHouseValue'
exec sp_addextendedproperty N'MS_Description', N'The average household income in the County based on 2000 Census data.', N'user', N'dbo', N'table', N'ZIPCodes', N'column', N'IncomePerHousehold'
exec sp_addextendedproperty N'MS_Description', N'The median age for all people based on 2000 Census data.', N'user', N'dbo', N'table', N'ZIPCodes', N'column', N'MedianAge'
exec sp_addextendedproperty N'MS_Description', N'The median age for males based on 2000 Census data.', N'user', N'dbo', N'table', N'ZIPCodes', N'column', N'MedianAgeMale'
exec sp_addextendedproperty N'MS_Description', N'The median age for females based on 2000 Census data.', N'user', N'dbo', N'table', N'ZIPCodes', N'column', N'MedianAgeFemale'
exec sp_addextendedproperty N'MS_Description', N'Geographic coordinate as a point measured in degrees north or south of the equator.', N'user', N'dbo', N'table', N'ZIPCodes', N'column', N'Latitude'
exec sp_addextendedproperty N'MS_Description', N'Geographic coordinate as a point measured in degrees east or west of the Greenwich Meridian.', N'user', N'dbo', N'table', N'ZIPCodes', N'column', N'Longitude'
exec sp_addextendedproperty N'MS_Description', N'The average elevation of the county.', N'user', N'dbo', N'table', N'ZIPCodes', N'column', N'Elevation'
exec sp_addextendedproperty N'MS_Description', N'2 letter state name abbreviation.', N'user', N'dbo', N'table', N'ZIPCodes', N'column', N'State'
exec sp_addextendedproperty N'MS_Description', N'The full US State Name.', N'user', N'dbo', N'table', N'ZIPCodes', N'column', N'StateFullName'
exec sp_addextendedproperty N'MS_Description', N'Indicates the type of locale such as Post Office, Stations, or Branch.', N'user', N'dbo', N'table', N'ZIPCodes', N'column', N'CityType'
exec sp_addextendedproperty N'MS_Description', N'13 Character abbreviation for the city alias name.', N'user', N'dbo', N'table', N'ZIPCodes', N'column', N'CityAliasAbbreviation'
exec sp_addextendedproperty N'MS_Description', N'The telephone area codes available in this ZIP Code.', N'user', N'dbo', N'table', N'ZIPCodes', N'column', N'AreaCode'
exec sp_addextendedproperty N'MS_Description', N'Name of the city as designated by the USPS.', N'user', N'dbo', N'table', N'ZIPCodes', N'column', N'City'
exec sp_addextendedproperty N'MS_Description', N'Alias name of the city if it exists.', N'user', N'dbo', N'table', N'ZIPCodes', N'column', N'CityAliasName'
exec sp_addextendedproperty N'MS_Description', N'Name of County or Parish this ZIP Code resides in.', N'user', N'dbo', N'table', N'ZIPCodes', N'column', N'County'
exec sp_addextendedproperty N'MS_Description', N'FIPS code for the County/Parish this ZIP Code resides in.', N'user', N'dbo', N'table', N'ZIPCodes', N'column', N'CountyFIPS'
exec sp_addextendedproperty N'MS_Description', N'FIPS code for the State this ZIP Code resides in.', N'user', N'dbo', N'table', N'ZIPCodes', N'column', N'StateFIPS'
exec sp_addextendedproperty N'MS_Description', N'Hours past Greenwich Time Zone this ZIP Code belongs to.', N'user', N'dbo', N'table', N'ZIPCodes', N'column', N'TimeZone'
exec sp_addextendedproperty N'MS_Description', N'Flag indicating whether this ZIP Code observes daylight savings.', N'user', N'dbo', N'table', N'ZIPCodes', N'column', N'DayLightSaving'
exec sp_addextendedproperty N'MS_Description', N'Metropolitan Statistical Area number assigned by Census 2000.', N'user', N'dbo', N'table', N'ZIPCodes', N'column', N'MSA'
exec sp_addextendedproperty N'MS_Description', N'Metropolitan Statistical Area name assigned by Census 2000.', N'user', N'dbo', N'table', N'ZIPCodes', N'column', N'MSA_Name'
exec sp_addextendedproperty N'MS_Description', N'Primary Metropolitan Statistical Area Number.', N'user', N'dbo', N'table', N'ZIPCodes', N'column', N'PMSA'
exec sp_addextendedproperty N'MS_Description', N'Primary Metropolitan Statistical Area name or Title.', N'user', N'dbo', N'table', N'ZIPCodes', N'column', N'PMSA_Name'
exec sp_addextendedproperty N'MS_Description', N'Core Statistical Area. This area is a group of MSA''s combined into a population core area.', N'user', N'dbo', N'table', N'ZIPCodes', N'column', N'CSA'
exec sp_addextendedproperty N'MS_Description', N'The name of the CSA this ZIP Code is in.', N'user', N'dbo', N'table', N'ZIPCodes', N'column', N'CSAName'
exec sp_addextendedproperty N'MS_Description', N'Core Based Statistical Area Number.', N'user', N'dbo', N'table', N'ZIPCodes', N'column', N'CBSA'
exec sp_addextendedproperty N'MS_Description', N'Core Based Statistical Area Division.', N'user', N'dbo', N'table', N'ZIPCodes', N'column', N'CBSA_DIV'
exec sp_addextendedproperty N'MS_Description', N'Core Based Statistical Area Type (Metro or Micro).', N'user', N'dbo', N'table', N'ZIPCodes', N'column', N'CBSA_Type'
exec sp_addextendedproperty N'MS_Description', N'Core Based Statistical Area Name or Title.', N'user', N'dbo', N'table', N'ZIPCodes', N'column', N'CBSA_Name'
exec sp_addextendedproperty N'MS_Description', N'The name of the CBSA Division this ZIP Code is in.', N'user', N'dbo', N'table', N'ZIPCodes', N'column', N'CBSA_DIV_Name'
exec sp_addextendedproperty N'MS_Description', N'The Region of the United States this record resides in.', N'user', N'dbo', N'table', N'ZIPCodes', N'column', N'Region'
exec sp_addextendedproperty N'MS_Description', N'The Division of the United States this record resides in.', N'user', N'dbo', N'table', N'ZIPCodes', N'column', N'Division'
exec sp_addextendedproperty N'MS_Description', N'Yes or No (Y/N) flag indicating whether or not the USPS accepts this City Alias Name for mailing purposes.', N'user', N'dbo', N'table', N'ZIPCodes', N'column', N'MailingName'
exec sp_addextendedproperty N'MS_Description', N'The total number of Business Establishments for this ZIP Code. Data taken from Census for 2003.', N'user', N'dbo', N'table', N'ZIPCodes', N'column', N'NumberOfBusinesses'
exec sp_addextendedproperty N'MS_Description', N'The total number of employees for this ZIP Code. Data taken from Census for 2003.', N'user', N'dbo', N'table', N'ZIPCodes', N'column', N'NumberOfEmployees'
exec sp_addextendedproperty N'MS_Description', N'The total payroll for the frist quarter this ZIP Code in $1000. Data taken from Census for 2003.', N'user', N'dbo', N'table', N'ZIPCodes', N'column', N'BusinessFirstQuarterPayroll'
exec sp_addextendedproperty N'MS_Description', N'The total annual payroll for this ZIP Code in $1000. Data taken from Census for 2003.', N'user', N'dbo', N'table', N'ZIPCodes', N'column', N'BusinessAnnualPayroll'
exec sp_addextendedproperty N'MS_Description', N'Due to confidentiality, some areas do not have actual figures for employment information. Employment and payroll data are replaced by zeroes with the Employment Flag denoting employment size class.', N'user', N'dbo', N'table', N'ZIPCodes', N'column', N'BusinessEmploymentFlag'
exec sp_addextendedproperty N'MS_Description', N'The rank in which this county is growing according to the US Census.', N'user', N'dbo', N'table', N'ZIPCodes', N'column', N'GrowthRank'
exec sp_addextendedproperty N'MS_Description', N'The estimated number of housing units in this county as of July 1, 2003.', N'user', N'dbo', N'table', N'ZIPCodes', N'column', N'GrowingCountiesA'
exec sp_addextendedproperty N'MS_Description', N'The estimated number of housing units in this county as of July 1, 2004. Source: Housing Unit Estimates for the 100 Fastest Growing U.S. Counties between July 1, 2003 and July 1, 2004. Population Division, U.S. Census Bureau.', N'user', N'dbo', N'table', N'ZIPCodes', N'column', N'GrowingCountiesB'
exec sp_addextendedproperty N'MS_Description', N'The change in housing units from 2003 to 2004, expressed as a number.', N'user', N'dbo', N'table', N'ZIPCodes', N'column', N'GrowthIncreaseNumber'
exec sp_addextendedproperty N'MS_Description', N'The change in housing units from 2003 to 2004, expressed as a percentage.', N'user', N'dbo', N'table', N'ZIPCodes', N'column', N'GrowthIncreasePercentage'
exec sp_addextendedproperty N'MS_Description', N'The estimated population for the selected CBSA in 2003. ', N'user', N'dbo', N'table', N'ZIPCodes', N'column', N'CBSAPopulation'
exec sp_addextendedproperty N'MS_Description', N'The estimated population for the selected CBSA Division in 2003.', N'user', N'dbo', N'table', N'ZIPCodes', N'column', N'CBSADivisionPopulation'
exec sp_addextendedproperty N'MS_Description', N'This field shows which 110th Congressional Districts the ZIP Code belongs to.', N'user', N'dbo', N'table', N'ZIPCodes', N'column', N'CongressionalDistrict'
exec sp_addextendedproperty N'MS_Description', N'This field provides the approximate land area covered by the Congressional District for which the ZIP Code belongs to.', N'user', N'dbo', N'table', N'ZIPCodes', N'column', N'CongressionalLandArea'
exec sp_addextendedproperty N'MS_Description', N'The number of active residential delivery mailboxes and centralized units for this ZIP Code. This excludes PO Boxes and all other contract box types. ', N'user', N'dbo', N'table', N'ZIPCodes', N'column', N'DeliveryResidential'
exec sp_addextendedproperty N'MS_Description', N'The number of active business delivery mailboxes and centralized units for this ZIP Code. This excludes PO Boxes and all other contract box types.', N'user', N'dbo', N'table', N'ZIPCodes', N'column', N'DeliveryBusiness'
exec sp_addextendedproperty N'MS_Description', N'The total number of delivery receptacles for this ZIP Code. This includes curb side mailboxes, centralized units, PO Boxes, NDCBU, and contract boxes.', N'user', N'dbo', N'table', N'ZIPCodes', N'column', N'DeliveryTotal'
exec sp_addextendedproperty N'MS_Description', N'Links this record with other products ZIP-Codes.com offers', N'user', N'dbo', N'table', N'ZIPCodes', N'column', N'PreferredLastLineKey'
exec sp_addextendedproperty N'MS_Description', N'The classification type of this ZIP Code.', N'user', N'dbo', N'table', N'ZIPCodes', N'column', N'ClassificationCode'
exec sp_addextendedproperty N'MS_Description', N'Flag indicating whether this ZIP Code crosses county lines.', N'user', N'dbo', N'table', N'ZIPCodes', N'column', N'MultiCounty'
exec sp_addextendedproperty N'MS_Description', N'Links this record with other products ZIP-Codes.com offers such as the ZIP+4.', N'user', N'dbo', N'table', N'ZIPCodes', N'column', N'CityStateKey'
exec sp_addextendedproperty N'MS_Description', N'An up to the month population estimate for this ZIP Code.', N'user', N'dbo', N'table', N'ZIPCodes', N'column', N'PopulationEstimate'
exec sp_addextendedproperty N'MS_Description', N'Code indicating the type of the city alias name for this record. Record can be Abbreviations, Universities, Government, and more.', N'user', N'dbo', N'table', N'ZIPCodes', N'column', N'CityAliasCode'
exec sp_addextendedproperty N'MS_Description', N'The city name in mixed case (i.e. Not in all uppercase letters).', N'user', N'dbo', N'table', N'ZIPCodes', N'column', N'CityMixedCase'
exec sp_addextendedproperty N'MS_Description', N'The city alias name in mixed case (i.e. Not in all uppercase letters).', N'user', N'dbo', N'table', N'ZIPCodes', N'column', N'CityAliasMixedCase'
exec sp_addextendedproperty N'MS_Description', N'Total count of PO Box deliveries in this ZIP Code.', N'user', N'dbo', N'table', N'ZIPCodes', N'column', N'BoxCount'
exec sp_addextendedproperty N'MS_Description', N'Total count of single family deliveries in this ZIP Code; generally analogous to homes.', N'user', N'dbo', N'table', N'ZIPCodes', N'column', N'SFDU'
exec sp_addextendedproperty N'MS_Description', N'Total count of multifamily deliveries in this ZIP Code; generally analogous to apartments.', N'user', N'dbo', N'table', N'ZIPCodes', N'column', N'MFDU'


exec sp_addextendedproperty N'MS_Description', N'American National Standards Institute codes (ANSI codes) are a standardized set of numeric or alphabetic codes issued by the American National Standards Institute (ANSI) to ensure uniform identification of geographic entities through all federal government agencies. These standards replace the Federal Information Processing Standards (FIPS) codes previously issued by the National Institute of Standards and Technology (NIST).', N'user', N'dbo', N'table', N'ZIPCodes', N'column', N'StateANSI'
exec sp_addextendedproperty N'MS_Description', N'American National Standards Institute codes (ANSI codes) are a standardized set of numeric or alphabetic codes issued by the American National Standards Institute (ANSI) to ensure uniform identification of geographic entities through all federal government agencies. These standards replace the Federal Information Processing Standards (FIPS) codes previously issued by the National Institute of Standards and Technology (NIST).', N'user', N'dbo', N'table', N'ZIPCodes', N'column', N'CountyANSI'
exec sp_addextendedproperty N'MS_Description', N'The type of locale identified in the city/state name. The facility may be a USPS facility, such as a post office, station, or branch, or it may be a non-postal place name.', N'user', N'dbo', N'table', N'ZIPCodes', N'column', N'FacilityCode'
exec sp_addextendedproperty N'MS_Description', N'Specifies whether or not a post office has city-delivery carrier routes.', N'user', N'dbo', N'table', N'ZIPCodes', N'column', N'CityDeliveryIndicator'
exec sp_addextendedproperty N'MS_Description', N'Short for Carrier Route Rate Sortation and Merged 5-Digit Indicator Identifies where automation Carrier Route rates are available and where the commingling of automation and non-automation mail, including Enhanced Carrier Routes and 5 digit presort, on the same pallet or in the same container is allowed. The values are A, B ,C or D.', N'user', N'dbo', N'table', N'ZIPCodes', N'column', N'CarrierRouteRateSortation'
exec sp_addextendedproperty N'MS_Description', N'A code assigned to Postal Service facilities (primarily post offices) to collect cost and statistical data and compile revenue and expense data. The state number comprises the first two positions of the finance number.', N'user', N'dbo', N'table', N'ZIPCodes', N'column', N'FinanceNumber'
exec sp_addextendedproperty N'MS_Description', N'Field that specifies whether the City State Record contains the organization name for a unique ZIP Code. If this field equals Y, the organization name will appear in the City State Name field.', N'user', N'dbo', N'table', N'ZIPCodes', N'column', N'UniqueZIPName'

GO