/*
------------------------------------------------------------------
Provider:  Zip-Codes.com
Product:   U.S. ZIP Code Database Business
------------------------------------------------------------------
This SQL Creates a new table named ZIPCodes, 
related indexes, and extended column information.

This script is designed to work with MySQL

Actions:
  1.) Drop Table ZIPCodes if it exists
  2.) Creates Table named ZIPCodes
  3.) Creates Indexes on table ZIPCodes
  4.) Creates Extended Table Information

Last Updated: 12/21/2007
------------------------------------------------------------------
*/


/* 1.) Drop Table if it Exists */
DROP TABLE IF EXISTS ZIPCodes;



/* 2.) Create Table */
CREATE TABLE ZIPCodes (
	ZipCode char(5) NOT NULL,
	PrimaryRecord char(1),
	Population int,
	HouseholdsPerZipcode int,
	WhitePopulation int,
	BlackPopulation int,
	HispanicPopulation int,
	AsianPopulation int,
	HawaiianPopulation int,
	IndianPopulation int,
	OtherPopulation int,
	MalePopulation int,
	FemalePopulation int,
	PersonsPerHousehold decimal(4, 2),
	AverageHouseValue int,
	IncomePerHousehold int,
	MedianAge decimal(3, 1),
	MedianAgeMale decimal(3, 1),
	MedianAgeFemale decimal(3, 1),
	Latitude decimal(12, 6),
	Longitude decimal(12, 6),
	Elevation int,
	State char(2),
	StateFullName varchar(35) NULL,
	CityType char(1) NULL,
	CityAliasAbbreviation varchar(13) NULL,
	AreaCode varchar(55) NULL,
	City varchar(35) NULL,
	CityAliasName varchar(35) NULL,
	County varchar(45) NULL,
	CountyFIPS char(5) NULL,
	StateFIPS char(2) NULL,
	TimeZone char(2) NULL,
	DayLightSaving char(1) NULL,
	MSA varchar(35) NULL,
	PMSA char(4) NULL,
	CSA char(3) NULL,
	CBSA char(5) NULL,
	CBSA_DIV char(5) NULL,
	CBSA_Type char(5) NULL,
	CBSA_Name varchar(150) NULL,
	MSA_Name varchar(150) NULL,
	PMSA_Name varchar(150) NULL,
	Region varchar(10) NULL,
	Division varchar(20) NULL,
	MailingName char(1) NULL,
	NumberOfBusinesses int,
	NumberOfEmployees int,
	BusinessFirstQuarterPayroll int,
	BusinessAnnualPayroll int,
	BusinessEmploymentFlag char(1) NULL,
	GrowthRank int,
	GrowingCountiesA int,
	GrowingCountiesB int,
	GrowthIncreaseNumber int,
	GrowthIncreasePercentage decimal(3, 1),
	CBSAPopulation int,
	CBSADivisionPopulation int,
	CongressionalDistrict varchar(150) NULL,
	CongressionalLandArea varchar(150) NULL,
	DeliveryResidential int,
	DeliveryBusiness int,
	DeliveryTotal int,
	PreferredLastLineKey varchar(10) NULL,
	ClassificationCode char(1) NULL,
	MultiCounty char(1) NULL,	
	CSAName varchar(150) NULL,	
	CBSA_DIV_Name varchar(150) NULL,	
	CityStateKey char(6) NULL,
	PopulationEstimate int,
	LandArea decimal(18, 6),
	WaterArea decimal(18, 6),
	CityAliasCode varchar(5) NULL,
	CityMixedCase varchar(35) NULL,
	CityAliasMixedCase varchar(35) NULL,
	BoxCount int NULL,
	SFDU int NULL,
	MFDU int NULL,
	StateANSI varchar(2) NULL,
	CountyANSI varchar(3) NULL,
	ZIPIntroDate varchar(15) NULL,
	AliasIntroDate varchar(15) NULL,
	FacilityCode char(1) NULL,
	CityDeliveryIndicator char(1) NULL,
	CarrierRouteRateSortation char(1) NULL,
	FinanceNumber varchar(10) NULL,
	UniqueZIPName char(1) NULL,
	SSAStateCountyCode varchar(255) NULL,
	MedicareCBSACode varchar(255) NULL,
	MedicareCBSAName varchar(255) NULL,
	MedicareCBSAType varchar(255) NULL,
	MarketRatingAreaID int NULL
);


/* 3.) Create Indexes on most searched fields */
CREATE INDEX Index_ZIPCodes_ZipCode					 ON ZIPCodes (ZipCode);
CREATE INDEX Index_ZIPCodes_State					 ON ZIPCodes (State);
CREATE INDEX Index_ZIPCodes_County					 ON ZIPCodes (County);
CREATE INDEX Index_ZIPCodes_AreaCode				 ON ZIPCodes (AreaCode);
CREATE INDEX Index_ZIPCodes_City					 ON ZIPCodes (City);
CREATE INDEX Index_ZIPCodes_Latitude				 ON ZIPCodes (Latitude);
CREATE INDEX Index_ZIPCodes_Longitude				 ON ZIPCodes (Longitude);
CREATE INDEX Index_ZIPCodes_CityAliasName			 ON ZIPCodes (CityAliasName);
CREATE INDEX Index_ZIPCodes_PrimaryRecord			 ON ZIPCodes (PrimaryRecord);
CREATE INDEX Index_ZIPCodes_CityStateKey			 ON ZIPCodes (CityStateKey);




/* 4.) Create Extended Column Information */
ALTER TABLE ZIPCodes COMMENT = 'U.S. Zip Code Database Business (from www.zip-codes.com)';
